function [u]=ode45a(neqn,t0,tf,u0,nsteps)
%
% Function ode45a computes an ODE solution by a fixed
% step, embedded RK (4,5) pair discussed by Shampine,
% L. F., I. Gladwell and S. Thompson, Solving ODEs with
% Matlab, Cambridge University Press, Cambridge, New York,
% 2003, p 53.
%
% Argument list
%
%   neqn     number of first order ODEs
%
%   t0       initial value of independent variable
%
%   tf       final value of independent variable
%
%   u0       initial condition vector of length neqn
%
%   nsteps   number of ode45 steps
%
%   u        ODE solution vector of length neqn after
%            nsteps steps
%
% Integration step
  h=(tf-t0)/nsteps;
%
% nsteps ode45 steps
  for i=1:nsteps
%
%   ode45 step
    [t,u,e]=ssode45(neqn,t0,u0,h);
%
%   Reset base point values for next ode45 step
    u0=u;
    t0=t;
%
% Next ode45 step
  end
%
% End of ode45a
